/*
 *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
 *
 *  $Id: id.c,v 1.2 2002/03/04 04:23:54 shuu Exp shuu $
 *
 *  Can be freely distributed and used under the terms of the GNU GPL.
 */
#include	<stdio.h>
#include	<stdlib.h>

#include	"murasaki.h"
#include	"murasaki_ieee1394.h"

int
get_id_ieee1394(MU_ieee1394_config_t *config)
{
	char *ptr;

	ptr = getenv("VENDOR_ID");
	config->vendor = strtoul(ptr,NULL,16);
/*
	Now, "GUID_ID" is not available
	ptr = getenv("GUID_ID");
*/
	ptr = getenv("SPECIFIER_ID");
	config->specifier = strtoul(ptr,NULL,16);
	ptr = getenv("VERSION");
	config->version = strtoul(ptr,NULL,16);
	
	return GOOD;	
}
